@@ -179,6 +179,9 @@ def set_idemailstatus_target_column(df):
         status_col = df['IDEmailStatus']
         df.drop( labels=['IDEmailStatus'], axis=1, inplace=True )
         df.insert(loc=0, value=status_col, column= 'IDEmailStatus')
+        bv_col = df['BV']
+        df.drop( labels=['BV'], axis=1, inplace=True )
+        df.insert( loc=1, value=bv_col, column='BV' )
     else:
         logger.error('No IDEmailSTatus column found')
         raise Exception('No IDEmailStatus column found!!!!!')
@@ -193,6 +196,10 @@ def set_bv_target_column(df):
         bv_col = df['BV']
         df.drop( labels=['BV'], axis=1, inplace=True )
         df.insert( loc=0, value=bv_col, column='BV' )
+        status_col = df['IDEmailStatus']
+        df.drop( labels=['IDEmailStatus'], axis=1, inplace=True )
+        df.insert(loc=1, value=status_col, column= 'IDEmailStatus')
+
     else:
         logger.error('No BV column found')
         raise Exception('No BV column found!!!!!')
